@@ -422,15 +422,19 @@ class RESTAPI :
             r_api = RiotApi(RIOT_KEY, REGIONS['north_america'])
             summoner = r_api.get_summoner_by_puuid(puuid)
             league = self.get_league_by_summonerid(summoner['id'])
+            print(league)
             if len(league) == [] :
                 api_url=URL['leagues'].format(url='/')
                 league = r_api.get_league_by_summoner_id(summoner['id'])
+                print(league)
                 self.post_league(league)
 
-            championMastery = self.get_championmastery_by_championid_and_summonerid(participant['championId'], summoner['id'])
+            championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], summoner['id'])
+            print(championMastery)
             if len(championMastery) == [] :
                 api_url=URL['championmasteries'].format(url='/')
                 championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
+                print(championMastery)
                 self.post_championMastery(championMastery)
         
             response = self.get_matchparticipant_by_matchid_and_puuid(match['metadata']['matchId'], puuid)
